

dkjason - Helper module to send json encoded data from Python
=============================================================

This module knows how to serialize general object, objects specialized
with a ``__json__()`` method, Django QuerySets, and ``ttcal`` objects.

.. image:: https://travis-ci.org/datakortet/dkjason.svg?branch=master
   :target: https://travis-ci.org/datakortet/dkjason
   :alt: Pipeline status

.. image:: https://readthedocs.org/projects/dkjason/badge/?version=latest
   :target: https://dkjason.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://codecov.io/gh/datakortet/dkjason/branch/master/graph/badge.svg?token=zmqdQHOX89
   :target: https://codecov.io/gh/datakortet/dkjason

